@@ -1,7 +1,7 @@
 from fluss.graphql.queries.graph import GET_GRAPH
 from fluss.diagram import Diagram
 from typing import Any, List, Optional
-from mikro.convenience import GraphQLModel
+from herre.convenience import GraphQLModel
 import xarray as xr
 from typing import ForwardRef
 from enum import Enum
